==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/WorkspaceApiVersionSetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin

import com.pulumi.azurenative.apimanagement.WorkspaceApiVersionSetArgs.builder
import com.pulumi.azurenative.apimanagement.kotlin.enums.VersioningScheme
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * API Version Set Contract details.
 * Azure REST API version: 2022-09-01-preview.
 * Other available API versions: 2023-03-01-preview.
 * ## Example Usage
 * ### ApiManagementCreateWorkspaceApiVersionSet
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var workspaceApiVersionSet = new AzureNative.ApiManagement.WorkspaceApiVersionSet("workspaceApiVersionSet", new()
 *     {
 *         Description = "Version configuration",
 *         DisplayName = "api set 1",
 *         ResourceGroupName = "rg1",
 *         ServiceName = "apimService1",
 *         VersionSetId = "api1",
 *         VersioningScheme = "Segment",
 *         WorkspaceId = "wks1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/apimanagement/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := apimanagement.NewWorkspaceApiVersionSet(ctx, "workspaceApiVersionSet", &apimanagement.WorkspaceApiVersionSetArgs{
 * 			Description:       pulumi.String("Version configuration"),
 * 			DisplayName:       pulumi.String("api set 1"),
 * 			ResourceGroupName: pulumi.String("rg1"),
 * 			ServiceName:       pulumi.String("apimService1"),
 * 			VersionSetId:      pulumi.String("api1"),
 * 			VersioningScheme:  pulumi.String("Segment"),
 * 			WorkspaceId:       pulumi.String("wks1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.apimanagement.WorkspaceApiVersionSet;
 * import com.pulumi.azurenative.apimanagement.WorkspaceApiVersionSetArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var workspaceApiVersionSet = new WorkspaceApiVersionSet("workspaceApiVersionSet", WorkspaceApiVersionSetArgs.builder()
 *             .description("Version configuration")
 *             .displayName("api set 1")
 *             .resourceGroupName("rg1")
 *             .serviceName("apimService1")
 *             .versionSetId("api1")
 *             .versioningScheme("Segment")
 *             .workspaceId("wks1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:apimanagement:WorkspaceApiVersionSet api1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ApiManagement/service/{serviceName}/workspaces/{workspaceId}/apiVersionSets/{versionSetId}
 * ```
 * @property description Description of API Version Set.
 * @property displayName Name of API Version Set
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property serviceName The name of the API Management service.
 * @property versionHeaderName Name of HTTP header parameter that indicates the API Version if versioningScheme is set to `header`.
 * @property versionQueryName Name of query parameter that indicates the API Version if versioningScheme is set to `query`.
 * @property versionSetId Api Version Set identifier. Must be unique in the current API Management service instance.
 * @property versioningScheme An value that determines where the API Version identifier will be located in a HTTP request.
 * @property workspaceId Workspace identifier. Must be unique in the current API Management service instance.
 */
public data class WorkspaceApiVersionSetArgs(
    public val description: Output<String>? = null,
    public val displayName: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val serviceName: Output<String>? = null,
    public val versionHeaderName: Output<String>? = null,
    public val versionQueryName: Output<String>? = null,
    public val versionSetId: Output<String>? = null,
    public val versioningScheme: Output<Either<String, VersioningScheme>>? = null,
    public val workspaceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.apimanagement.WorkspaceApiVersionSetArgs> {
    override fun toJava(): com.pulumi.azurenative.apimanagement.WorkspaceApiVersionSetArgs =
        com.pulumi.azurenative.apimanagement.WorkspaceApiVersionSetArgs.builder()
            .description(description?.applyValue({ args0 -> args0 }))
            .displayName(displayName?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .serviceName(serviceName?.applyValue({ args0 -> args0 }))
            .versionHeaderName(versionHeaderName?.applyValue({ args0 -> args0 }))
            .versionQueryName(versionQueryName?.applyValue({ args0 -> args0 }))
            .versionSetId(versionSetId?.applyValue({ args0 -> args0 }))
            .versioningScheme(
                versioningScheme?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .workspaceId(workspaceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkspaceApiVersionSetArgs].
 */
@PulumiTagMarker
public class WorkspaceApiVersionSetArgsBuilder internal constructor() {
    private var description: Output<String>? = null

    private var displayName: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var serviceName: Output<String>? = null

    private var versionHeaderName: Output<String>? = null

    private var versionQueryName: Output<String>? = null

    private var versionSetId: Output<String>? = null

    private var versioningScheme: Output<Either<String, VersioningScheme>>? = null

    private var workspaceId: Output<String>? = null

    /**
     * @param value Description of API Version Set.
     */
    @JvmName("vyyorwnrkltxkack")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Name of API Version Set
     */
    @JvmName("vrxvnqpybuasquww")
    public suspend fun displayName(`value`: Output<String>) {
        this.displayName = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("bjjsouimwutaocso")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the API Management service.
     */
    @JvmName("wagadgdllhjvojdh")
    public suspend fun serviceName(`value`: Output<String>) {
        this.serviceName = value
    }

    /**
     * @param value Name of HTTP header parameter that indicates the API Version if versioningScheme is set to `header`.
     */
    @JvmName("irtgnxhxwboqnaht")
    public suspend fun versionHeaderName(`value`: Output<String>) {
        this.versionHeaderName = value
    }

    /**
     * @param value Name of query parameter that indicates the API Version if versioningScheme is set to `query`.
     */
    @JvmName("feuntxftlvqskxyq")
    public suspend fun versionQueryName(`value`: Output<String>) {
        this.versionQueryName = value
    }

    /**
     * @param value Api Version Set identifier. Must be unique in the current API Management service instance.
     */
    @JvmName("exinkjjuleyqkppn")
    public suspend fun versionSetId(`value`: Output<String>) {
        this.versionSetId = value
    }

    /**
     * @param value An value that determines where the API Version identifier will be located in a HTTP request.
     */
    @JvmName("cksexaixbxwdjnup")
    public suspend fun versioningScheme(`value`: Output<Either<String, VersioningScheme>>) {
        this.versioningScheme = value
    }

    /**
     * @param value Workspace identifier. Must be unique in the current API Management service instance.
     */
    @JvmName("mkabweuhnlvkbenc")
    public suspend fun workspaceId(`value`: Output<String>) {
        this.workspaceId = value
    }

    /**
     * @param value Description of API Version Set.
     */
    @JvmName("oofrkindgqgsgnuj")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Name of API Version Set
     */
    @JvmName("bwgglsqnydoldpuf")
    public suspend fun displayName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.displayName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("jlvirrygitccavko")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the API Management service.
     */
    @JvmName("nqhchaahngaatorg")
    public suspend fun serviceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceName = mapped
    }

    /**
     * @param value Name of HTTP header parameter that indicates the API Version if versioningScheme is set to `header`.
     */
    @JvmName("geykegwnwncgddqo")
    public suspend fun versionHeaderName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.versionHeaderName = mapped
    }

    /**
     * @param value Name of query parameter that indicates the API Version if versioningScheme is set to `query`.
     */
    @JvmName("rrwjtwfrweonlvuo")
    public suspend fun versionQueryName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.versionQueryName = mapped
    }

    /**
     * @param value Api Version Set identifier. Must be unique in the current API Management service instance.
     */
    @JvmName("dxwnwmjsxuslkbcs")
    public suspend fun versionSetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.versionSetId = mapped
    }

    /**
     * @param value An value that determines where the API Version identifier will be located in a HTTP request.
     */
    @JvmName("xjexektsjenflgby")
    public suspend fun versioningScheme(`value`: Either<String, VersioningScheme>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.versioningScheme = mapped
    }

    /**
     * @param value An value that determines where the API Version identifier will be located in a HTTP request.
     */
    @JvmName("cxfpwngtqbwhuoib")
    public fun versioningScheme(`value`: String) {
        val toBeMapped = Either.ofLeft<String, VersioningScheme>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.versioningScheme = mapped
    }

    /**
     * @param value An value that determines where the API Version identifier will be located in a HTTP request.
     */
    @JvmName("hjdmujwirckgheqq")
    public fun versioningScheme(`value`: VersioningScheme) {
        val toBeMapped = Either.ofRight<String, VersioningScheme>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.versioningScheme = mapped
    }

    /**
     * @param value Workspace identifier. Must be unique in the current API Management service instance.
     */
    @JvmName("vmnveinoamiogsui")
    public suspend fun workspaceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.workspaceId = mapped
    }

    internal fun build(): WorkspaceApiVersionSetArgs = WorkspaceApiVersionSetArgs(
        description = description,
        displayName = displayName,
        resourceGroupName = resourceGroupName,
        serviceName = serviceName,
        versionHeaderName = versionHeaderName,
        versionQueryName = versionQueryName,
        versionSetId = versionSetId,
        versioningScheme = versioningScheme,
        workspaceId = workspaceId,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/WorkspaceApiVersionSetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin

import com.pulumi.azurenative.apimanagement.WorkspaceApiVersionSetArgs.builder
import com.pulumi.azurenative.apimanagement.kotlin.enums.VersioningScheme
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * API Version Set Contract details.
 * Azure REST API version: 2022-09-01-preview.
 * Other available API versions: 2023-03-01-preview, 2023-05-01-preview.
 * ## Example Usage
 * ### ApiManagementCreateWorkspaceApiVersionSet
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var workspaceApiVersionSet = new AzureNative.ApiManagement.WorkspaceApiVersionSet("workspaceApiVersionSet", new()
 *     {
 *         Description = "Version configuration",
 *         DisplayName = "api set 1",
 *         ResourceGroupName = "rg1",
 *         ServiceName = "apimService1",
 *         VersionSetId = "api1",
 *         VersioningScheme = "Segment",
 *         WorkspaceId = "wks1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/apimanagement/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := apimanagement.NewWorkspaceApiVersionSet(ctx, "workspaceApiVersionSet", &apimanagement.WorkspaceApiVersionSetArgs{
 * 			Description:       pulumi.String("Version configuration"),
 * 			DisplayName:       pulumi.String("api set 1"),
 * 			ResourceGroupName: pulumi.String("rg1"),
 * 			ServiceName:       pulumi.String("apimService1"),
 * 			VersionSetId:      pulumi.String("api1"),
 * 			VersioningScheme:  pulumi.String("Segment"),
 * 			WorkspaceId:       pulumi.String("wks1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.apimanagement.WorkspaceApiVersionSet;
 * import com.pulumi.azurenative.apimanagement.WorkspaceApiVersionSetArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var workspaceApiVersionSet = new WorkspaceApiVersionSet("workspaceApiVersionSet", WorkspaceApiVersionSetArgs.builder()
 *             .description("Version configuration")
 *             .displayName("api set 1")
 *             .resourceGroupName("rg1")
 *             .serviceName("apimService1")
 *             .versionSetId("api1")
 *             .versioningScheme("Segment")
 *             .workspaceId("wks1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:apimanagement:WorkspaceApiVersionSet api1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ApiManagement/service/{serviceName}/workspaces/{workspaceId}/apiVersionSets/{versionSetId}
 * ```
 * @property description Description of API Version Set.
 * @property displayName Name of API Version Set
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property serviceName The name of the API Management service.
 * @property versionHeaderName Name of HTTP header parameter that indicates the API Version if versioningScheme is set to `header`.
 * @property versionQueryName Name of query parameter that indicates the API Version if versioningScheme is set to `query`.
 * @property versionSetId Api Version Set identifier. Must be unique in the current API Management service instance.
 * @property versioningScheme An value that determines where the API Version identifier will be located in a HTTP request.
 * @property workspaceId Workspace identifier. Must be unique in the current API Management service instance.
 */
public data class WorkspaceApiVersionSetArgs(
    public val description: Output<String>? = null,
    public val displayName: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val serviceName: Output<String>? = null,
    public val versionHeaderName: Output<String>? = null,
    public val versionQueryName: Output<String>? = null,
    public val versionSetId: Output<String>? = null,
    public val versioningScheme: Output<Either<String, VersioningScheme>>? = null,
    public val workspaceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.apimanagement.WorkspaceApiVersionSetArgs> {
    override fun toJava(): com.pulumi.azurenative.apimanagement.WorkspaceApiVersionSetArgs =
        com.pulumi.azurenative.apimanagement.WorkspaceApiVersionSetArgs.builder()
            .description(description?.applyValue({ args0 -> args0 }))
            .displayName(displayName?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .serviceName(serviceName?.applyValue({ args0 -> args0 }))
            .versionHeaderName(versionHeaderName?.applyValue({ args0 -> args0 }))
            .versionQueryName(versionQueryName?.applyValue({ args0 -> args0 }))
            .versionSetId(versionSetId?.applyValue({ args0 -> args0 }))
            .versioningScheme(
                versioningScheme?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .workspaceId(workspaceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkspaceApiVersionSetArgs].
 */
@PulumiTagMarker
public class WorkspaceApiVersionSetArgsBuilder internal constructor() {
    private var description: Output<String>? = null

    private var displayName: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var serviceName: Output<String>? = null

    private var versionHeaderName: Output<String>? = null

    private var versionQueryName: Output<String>? = null

    private var versionSetId: Output<String>? = null

    private var versioningScheme: Output<Either<String, VersioningScheme>>? = null

    private var workspaceId: Output<String>? = null

    /**
     * @param value Description of API Version Set.
     */
    @JvmName("twymtvfhoucmvbki")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Name of API Version Set
     */
    @JvmName("kqxluicegsixfpjo")
    public suspend fun displayName(`value`: Output<String>) {
        this.displayName = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("gqgqnuqxnlxdwwmq")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the API Management service.
     */
    @JvmName("ohlltydsxtwyunvi")
    public suspend fun serviceName(`value`: Output<String>) {
        this.serviceName = value
    }

    /**
     * @param value Name of HTTP header parameter that indicates the API Version if versioningScheme is set to `header`.
     */
    @JvmName("bteftrvdxaeevpyy")
    public suspend fun versionHeaderName(`value`: Output<String>) {
        this.versionHeaderName = value
    }

    /**
     * @param value Name of query parameter that indicates the API Version if versioningScheme is set to `query`.
     */
    @JvmName("ciwxnhfgjloyvjsr")
    public suspend fun versionQueryName(`value`: Output<String>) {
        this.versionQueryName = value
    }

    /**
     * @param value Api Version Set identifier. Must be unique in the current API Management service instance.
     */
    @JvmName("bljeygsvpyhcbtao")
    public suspend fun versionSetId(`value`: Output<String>) {
        this.versionSetId = value
    }

    /**
     * @param value An value that determines where the API Version identifier will be located in a HTTP request.
     */
    @JvmName("kkywrmsikxqbmxaf")
    public suspend fun versioningScheme(`value`: Output<Either<String, VersioningScheme>>) {
        this.versioningScheme = value
    }

    /**
     * @param value Workspace identifier. Must be unique in the current API Management service instance.
     */
    @JvmName("tuxxwoqylpwchjlx")
    public suspend fun workspaceId(`value`: Output<String>) {
        this.workspaceId = value
    }

    /**
     * @param value Description of API Version Set.
     */
    @JvmName("hdynghkhogkinrxv")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Name of API Version Set
     */
    @JvmName("stbsdpgaxjcoiwgh")
    public suspend fun displayName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.displayName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("nngdlhjumqjacmaq")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the API Management service.
     */
    @JvmName("xruadxihdqpfiduj")
    public suspend fun serviceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceName = mapped
    }

    /**
     * @param value Name of HTTP header parameter that indicates the API Version if versioningScheme is set to `header`.
     */
    @JvmName("fgjdjqeefdljbofa")
    public suspend fun versionHeaderName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.versionHeaderName = mapped
    }

    /**
     * @param value Name of query parameter that indicates the API Version if versioningScheme is set to `query`.
     */
    @JvmName("gegqkuxuccxirknq")
    public suspend fun versionQueryName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.versionQueryName = mapped
    }

    /**
     * @param value Api Version Set identifier. Must be unique in the current API Management service instance.
     */
    @JvmName("sovhmdurnnuofweq")
    public suspend fun versionSetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.versionSetId = mapped
    }

    /**
     * @param value An value that determines where the API Version identifier will be located in a HTTP request.
     */
    @JvmName("imphmferycntgtvq")
    public suspend fun versioningScheme(`value`: Either<String, VersioningScheme>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.versioningScheme = mapped
    }

    /**
     * @param value An value that determines where the API Version identifier will be located in a HTTP request.
     */
    @JvmName("apnlstksskjjugye")
    public fun versioningScheme(`value`: String) {
        val toBeMapped = Either.ofLeft<String, VersioningScheme>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.versioningScheme = mapped
    }

    /**
     * @param value An value that determines where the API Version identifier will be located in a HTTP request.
     */
    @JvmName("bkseaxpvoweiwbsx")
    public fun versioningScheme(`value`: VersioningScheme) {
        val toBeMapped = Either.ofRight<String, VersioningScheme>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.versioningScheme = mapped
    }

    /**
     * @param value Workspace identifier. Must be unique in the current API Management service instance.
     */
    @JvmName("xfaxlbucobddywan")
    public suspend fun workspaceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.workspaceId = mapped
    }

    internal fun build(): WorkspaceApiVersionSetArgs = WorkspaceApiVersionSetArgs(
        description = description,
        displayName = displayName,
        resourceGroupName = resourceGroupName,
        serviceName = serviceName,
        versionHeaderName = versionHeaderName,
        versionQueryName = versionQueryName,
        versionSetId = versionSetId,
        versioningScheme = versioningScheme,
        workspaceId = workspaceId,
    )
}
